@@ -105,7 +105,10 @@ class CPU(object):
 		"""
 			Return the model string of this CPU.
 		"""
-		return self.__cpuinfo["Processor"]
+		try:
+			return self.__cpuinfo["model_name"]
+		except KeyError:
+			return self.__cpuinfo["Processor"]
 
 	@property
 	def vendor(self):
@@ -191,8 +194,6 @@ if __name__ == "__main__":
 	print "Flags:", c.flags
 	print "Bogomips:", c.bogomips
 	print "Speed:", c.speed
-	print "Hypervisor:", c.hypervisor
-	print "Virtype:", c.virtype
 	print "Family:", c.family
 	print "Count:", c.count
 	print "Model string:", c.model_string
